#!/bin/bash

# toolchain information to setup the environment with appropriate variables so the cross-compiler is used
TOOLCHAIN=~/ti-processor-sdk-linux-am62xx-evm-08.06.00.42/linux-devkit/environment-setup #-aarch64-linux
source $TOOLCHAIN

CC_PREFIX=aarch64-none-linux-gnu

# this script assumes there is a makefile in the same directory as this script and that the 
# working directory when executing this script is the directory containing this script.
#
# In addition, this script assumes there is a Qt project file used to generate the makefile.
# 

#PRO_FILE=target.pro
PRO_FILE=hello.pro

# this script can be called with an argument which is the target for the call to make
# if no argument is given, then "all" is used.
# Other values for the argument include
#
# debug
# release
# clean
# debug-clean
# release-clean
MAKE_TARGET=release
if [ "$1" != "" ]
then
    MAKE_TARGET=$1
fi

#set -e
#set -x

# Build app
COMPILEDB=
if command -v compiledb &> /dev/null
then
    # Use compiledb to generate a compile_commands.json file for vscode
    COMPILEDB="compiledb"
fi

(
    # make sure that if there is a PRO_FILE (meaning that Qt and qmake are being used) then
    # the Makefile exists and is that the PRO_FILE is older than the Makefile
    # if the Makefile does not exist or the PRO_FILE is not older than the Makefile
    # then call qmake to generate the Makefile
    #
    # note that the Makefile itself does some checks about whether the Makefile is up to date
    # but it won't catch the Makefile not existing or if PRO_FILE and Makefile have the 
    # same date/time. The checks below are intended to make sure the PRO_FILE is older
    # than the Makefile

    if [ "$PRO_FILE" != "" ]
    then
        if [[ ! -e Makefile ]] ||  [[ !  "$PRO_FILE" -ot Makefile  ]]
        then
            echo Generating Makefile from $PRO_FILE
            qmake "$PRO_FILE"
        fi
    fi
    $COMPILEDB make -j$(nproc) $MAKE_TARGET
)

